@@ -100,41 +100,41 @@ def get_parser():
         help="if --password-file is not supplied a password will be prompted "
         "for interactively")
 
-    submit_p = subparsers.add_parser(
+    submit= subparsers.add_parser(
         "submit",
         parents=[api_actions],
         help="submit qprofiler2 outputs to be analyzed and generate job "
         "manifest file")
-    submit_p.add_argument(
+    submit.add_argument(
         "files",
         metavar="QPXML",
         type=argparse.FileType('rb'),
         nargs='+')
-    submit_p.add_argument(
+    submit.add_argument(
         "--manifest-file",
         required=True,
         # exclusive new write (fail if exists)
         type=argparse.FileType('x'),
         help="name of the job manifest file that will be created")
 
-    get_status_p = subparsers.add_parser(
+    get_status= subparsers.add_parser(
         "get_status",
         parents=[api_actions],
         help="check and update status of jobs listed in a manifest file")
-    get_status_p.add_argument(
+    get_status.add_argument(
         "--manifest-file",
         required=True,
         type=argparse.FileType('r'))
 
-    get_results_p = subparsers.add_parser(
+    get_results= subparsers.add_parser(
         "get_results",
         parents=[api_actions],
         help="get results of completed jobs listed in a manifest file")
-    get_results_p.add_argument(
+    get_results.add_argument(
         "--manifest-file",
         required=True,
         type=argparse.FileType('r'))
-    get_results_p.add_argument(
+    get_results.add_argument(
         "--include-logs",
         action='store_true',
         help="also get log files, may be useful to troubleshoot failed jobs")
